# coding: utf-8

"""
    WordLift API

    WordLift API

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.js_rendering import JsRendering

class TestJsRendering(unittest.TestCase):
    """JsRendering unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JsRendering:
        """Test JsRendering
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JsRendering`
        """
        model = JsRendering()
        if include_optional:
            return JsRendering(
                status = 'Excellent',
                explanation = '',
                framework_detected = '',
                rendering_type = 'Static',
                ai_accessibility = 'Excellent',
                content_availability = '',
                recommendations = [
                    ''
                    ]
            )
        else:
            return JsRendering(
        )
        """

    def testJsRendering(self):
        """Test JsRendering"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
